"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toFulfilment = exports.extractSettledValues = exports.extractFulfilledValues = exports.filterLeft = exports.filterRight = void 0;
var tslib_1 = require("tslib");
var constants_1 = require("../../constants");
var makeFulfillement_1 = require("../../functions/core/makeFulfillement");
var assertions_1 = require("../assertions");
var isSettled_1 = require("../assertions/isSettled");
/**
 * Function `filterRight` takes an array of `Settled<R>` and returns an array of `SettledRight<R>` values.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `SettledRight<R>` values
 * @public
 */
function filterRight(settledArray) {
    return settledArray.filter(assertions_1.isSettledRight);
}
exports.filterRight = filterRight;
/**
 * Function `filterLeft` takes an array of `Settled<R>` and returns an array of `SettledLeft` values.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `SettledLeft` values
 * @public
 */
function filterLeft(settledArray) {
    return settledArray.filter(isSettled_1.isSettledLeft);
}
exports.filterLeft = filterLeft;
/**
 * Function `extractFulfilledValues` takes an array of `Settled<R>` and returns an array
 * of `R` values, filtering out any `null` or union types that include `null`.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `R` values, filtering out any `null` or union types that include `null`.
 * @public
 */
function extractFulfilledValues(settledArray) {
    return filterRight(settledArray).map(function (settled) { return settled.value; });
}
exports.extractFulfilledValues = extractFulfilledValues;
/**
 * Function `extractSettledValues` takes an array of `Settled<R>` and returns an array
 * of `R` values, with a default value of `NULL_SYMBOL` in place of
 * `SettledLeft` elements which do not have a value to be returned.
 *
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `R` values, with a default value of
 * `NULL_SYMBOL` in place of `SettledLeft` wich lack of a value.
 * @public
 */
function extractSettledValues(settledArray) {
    var result = settledArray.map(function (settled) {
        if (settled.status === 'fulfilled' && 'value' in settled) {
            return settled.value;
        }
        return constants_1.NULL_SYMBOL;
    });
    return result;
}
exports.extractSettledValues = extractSettledValues;
/**
 * Function `toFulfilment` takes an array or iterable of any values `T`
 * and returns a `SettledRight<T>[]`.
 *
 * @param list - an array or iterable of any values T
 * @returns an array of `SettledRight<T>`.
 * @public
 */
function toFulfilment(list) {
    return tslib_1.__spreadArray([], tslib_1.__read(list), false).map(function (value, index) {
        return (0, makeFulfillement_1.makeFulfillement)({ value: value, index: index, transformStep: 0 });
    });
}
exports.toFulfilment = toFulfilment;
// TASK LIST: (Review Documentation) [TODO: Types]  ------------------
//# sourceMappingURL=extractValues.js.map