import { NULL_SYMBOL } from '../../constants';
import { Settled, SettledLeft, SettledRight } from '../../types';
/**
 * Function `filterRight` takes an array of `Settled<R>` and returns an array of `SettledRight<R>` values.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `SettledRight<R>` values
 * @public
 */
export declare function filterRight<R>(settledArray: Settled<R>[]): SettledRight<R>[];
/**
 * Function `filterLeft` takes an array of `Settled<R>` and returns an array of `SettledLeft` values.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `SettledLeft` values
 * @public
 */
export declare function filterLeft<R>(settledArray: Settled<R>[]): SettledLeft[];
/**
 * Function `extractFulfilledValues` takes an array of `Settled<R>` and returns an array
 * of `R` values, filtering out any `null` or union types that include `null`.
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `R` values, filtering out any `null` or union types that include `null`.
 * @public
 */
export declare function extractFulfilledValues<R>(settledArray: Settled<R>[]): R[];
/**
 * Function `extractSettledValues` takes an array of `Settled<R>` and returns an array
 * of `R` values, with a default value of `NULL_SYMBOL` in place of
 * `SettledLeft` elements which do not have a value to be returned.
 *
 * @param settledArray - an array of `Settled<R>`
 * @returns an array of `R` values, with a default value of
 * `NULL_SYMBOL` in place of `SettledLeft` wich lack of a value.
 * @public
 */
export declare function extractSettledValues<R>(settledArray: Settled<R>[]): (R | typeof NULL_SYMBOL)[];
/**
 * Function `toFulfilment` takes an array or iterable of any values `T`
 * and returns a `SettledRight<T>[]`.
 *
 * @param list - an array or iterable of any values T
 * @returns an array of `SettledRight<T>`.
 * @public
 */
export declare function toFulfilment<T>(list: Iterable<T>): SettledRight<T>[];
//# sourceMappingURL=extractValues.d.ts.map